var jPhidget22 = require('phidget22');

var SERVER_PORT = 5661;

function main() {

	if (process.argv.length != 3) {
		console.log('usage: node DCMotor.js <server address>');
		process.exit(1);
	}

	var url = 'phid://' + process.argv[2] + ':' + SERVER_PORT;

	console.log('connecting to:' + url);
	var conn = new jPhidget22.Connection(url, { name: 'Server Connection', passwd: '' });
	conn.connect()
	  .then(runExample)
	  .catch(function (err) {
	  	console.log('Error running example:' + err);
		process.exit(1);
	  });
}

function runExample() {

	console.log('connected to server');
	var ch = new jPhidget22.DCMotor();
	
	var exTimer;
	
	function updateVelocity() {
		var newVelocity = ch.getTargetVelocity() + 0.5;
		if(newVelocity > 1)
			newVelocity = -1;
		console.log('Setting velocity to ' + newVelocity + ' for 5 seconds...');
		ch.setTargetVelocity(newVelocity);
	}
	
	ch.onAttach = function(ch) {
		console.log(ch + ' attached');
		exTimer = setInterval(function () { updateVelocity() } , 5000);
	};

	ch.onDetach = function(ch) {
		console.log(ch + ' detached');
		clearInterval(exTimer);
	};
	
	ch.onVelocityUpdate = function (velocity) {
        console.log('velocity:' + velocity + ' (' + this.getVelocity() + ')');
	};
	
	ch.onBackEMFChange = function (backEMF) {
        console.log('backEMF:' + backEMF + ' (' + this.getBackEMF() + ')');
	};
	
	ch.onBrakingStrengthUpdate = function (brakingStrength) {
		console.log('brakingStrength:' + brakingStrength + ' (' + this.getBrakingStrength() + ')');
	};

	ch.open().then(function (ch) {
		console.log('channel open');
	}).catch(function (err) {
		console.log('failed to open the channel:' + err);
	});
}

if (require.main === module)
	main();
